summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
commit03256f3cd5149f3ff5f5f45765b0b0659db4e036 (patch)
treecaabe9e1c0e3edfd06ea5aefd4d7279664cd9ede /experimental/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c
parent0594950f65a713c2d12e8eb6ddd3f5f9b306ec08 (diff)
downloadtde-03256f3cd5149f3ff5f5f45765b0b0659db4e036.tar.gz
tde-03256f3cd5149f3ff5f5f45765b0b0659db4e036.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains
Diffstat (limited to 'experimental/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c')
-rw-r--r--experimental/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/experimental/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c b/experimental/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c
index a69573161..167215f9e 100644
--- a/experimental/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c
+++ b/experimental/tqtinterface/qt4/src/3rdparty/libpng/pngrtran.c
@@ -7,7 +7,7 @@
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
- * This file tqcontains functions optionally called by an application
+ * This file contains functions optionally called by an application
* in order to tell libpng how to handle data when reading a PNG.
* Transformations that are used in both reading and writing are
* in pngtrans.c.
@@ -179,7 +179,7 @@ png_set_dither(png_structp png_ptr, png_colorp palette,
/* Find the least used palette entries by starting a
bubble sort, and running it until we have sorted
out enough colors. Note that we don't care about
- sorting all the colors, just tqfinding which are
+ sorting all the colors, just finding which are
least used. */
for (i = num_palette - 1; i >= maximum_colors; i--)
@@ -249,14 +249,14 @@ png_set_dither(png_structp png_ptr, png_colorp palette,
}
}
/* tqfind closest color for those colors we are not using */
for (i = 0; i < num_palette; i++)
{
if ((int)png_ptr->dither_index[i] >= maximum_colors)
{
int min_d, k, min_k, d_index;
/* tqfind the closest color to one we threw out */
d_index = png_ptr->dither_index[i];
min_d = PNG_COLOR_DIST(palette[d_index], palette[0]);
for (k = 1, min_k = 0; k < maximum_colors; k++)
@@ -284,7 +284,7 @@ png_set_dither(png_structp png_ptr, png_colorp palette,
/* This is much harder to do simply (and quickly). Perhaps
we need to go through a median cut routine, but those
don't always behave themselves with only a few colors
- as input. So we will just tqfind the closest two colors,
+ as input. So we will just find the closest two colors,
and throw out one of them (chosen somewhat randomly).
[We don't understand this at all, so if someone wants to
work on improving it, be our guest - AED, GRP]
@@ -551,7 +551,7 @@ png_set_expand(png_structp png_ptr)
* to png_set_expand(). However, it is entirely reasonable that someone
* might wish to expand an indexed image to RGB but *not* expand a single,
* fully transtqparent palette entry to a full alpha channel--perhaps instead
* convert tRNS to the grayscale/RGB format (16-bit RGB value), or tqreplace
* the transtqparent color with a particular RGB value, or drop tRNS entirely.
* IOW, a future version of the library may make the transformations flag
* a bit more fine-grained, with separate bits for each of these three
@@ -1762,7 +1762,7 @@ png_do_read_invert_alpha(png_row_infop row_info, png_bytep row)
*(--dp) = *(--sp);
*(--dp) = *(--sp);
*(--dp) = *(--sp);
- We can tqreplace it with:
+ We can replace it with:
*/
sp-=3;
dp=sp;
@@ -1787,7 +1787,7 @@ png_do_read_invert_alpha(png_row_infop row_info, png_bytep row)
*(--dp) = *(--sp);
*(--dp) = *(--sp);
*(--dp) = *(--sp);
- We can tqreplace it with:
+ We can replace it with:
*/
sp-=6;
dp=sp;
@@ -249,14 +249,14 @@ png_set_dither(png_structp png_ptr, png_colorp palette,
}
}
- /* tqfind closest color for those colors we are not using */
+ /* find closest color for those colors we are not using */
for (i = 0; i < num_palette; i++)
{
@@ -249,14 +249,14 @@ png_set_dither(png_structp png_ptr, png_colorp palette,
{
int min_d, k, min_k, d_index;
- /* tqfind the closest color to one we threw out */
+ /* find the closest color to one we threw out */
d_index = png_ptr->dither_index[i];
min_d = PNG_COLOR_DIST(palette[d_index], palette[0]);
@@ -551,7 +551,7 @@ png_set_expand(png_structp png_ptr)
* might wish to expand an indexed image to RGB but *not* expand a single,
* fully transtqparent palette entry to a full alpha channel--perhaps instead
- * convert tRNS to the grayscale/RGB format (16-bit RGB value), or tqreplace
+ * convert tRNS to the grayscale/RGB format (16-bit RGB value), or replace
* the transtqparent color with a particular RGB value, or drop tRNS entirely.
* IOW, a future version of the library may make the transformations flag